@@ -8,10 +8,11 @@
     } else {
       ## Return POSIX or Date, depending on format
       if (data$format == "POSIX") {
-        # res <- try(as.POSIXct(c(data$start, data$end)), silent = TRUE)
         res <- try(as.POSIXct(c(data$start, data$end),
-                              origin = "1970-01-01 00:00:00"),
-                   silent = TRUE)
+          origin = "1970-01-01 00:00:00"
+        ),
+        silent = TRUE
+        )
       } else {
         res <- try(as.Date(c(data$start, data$end)), silent = TRUE)
       }
